<?php

namespace App\Filament\Resources;

use App\Filament\Resources\CaseManagementResource\Pages;
use App\Filament\Resources\CaseManagementResource\RelationManagers;
use App\Models\CaseManagement;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Mohamedsabil83\FilamentFormsTinyeditor\Components\TinyEditor;


class CaseManagementResource extends Resource
{
    protected static ?string $model = CaseManagement::class;

    public static function getModelLabel(): string
    {
        return __('caseManagement.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                // Forms\Components\Select::make('physician_id')
                //     ->label(__('caseManagement.physician'))
                //     ->relationship('physician', 'name')
                //     ->required()
                //     ->translateLabel(),
                // Forms\Components\Select::make('nurse_id')
                //     ->label(__('caseManagement.nurse'))
                //     ->relationship('nurse', 'name')
                //     ->required(),
                // Forms\Components\Select::make('paramedic_id')
                //     ->label(__('caseManagement.paramedic'))
                //     ->relationship('paramedic', 'name')
                //     ->required(),
                Forms\Components\Select::make('rapid_risk_assessments_id')
                    ->label(__('caseManagement.rapid_risk_assessments'))
                    ->relationship('rapid_risk_assessments', 'name')
                    ->required(),
                Forms\Components\Select::make('clinical_management_advice_and_recommendations_id')
                    ->label(__('caseManagement.clinical_management_advice_and_recommendations'))
                    ->relationship('clinical_management_advice_and_recommendations', 'name')
                    ->required(),
                Forms\Components\Select::make('icp_in_the_care_facility_id')
                    ->label(__('caseManagement.icp_in_the_care_facility'))
                    ->relationship('icp_in_the_care_facility', 'name')
                    ->required(),
                Forms\Components\Select::make('monitoring_system_id')
                    ->label(__('caseManagement.monitoring_system'))
                    ->relationship('monitoring_system', 'name')
                    ->required(),
                
                Forms\Components\Select::make('determination_of_disease_status_id')
                    ->label(__('caseManagement.determination_of_disease_status'))
                    ->relationship('determination_of_disease_status', 'name')
                    ->required(),
                
                // Forms\Components\Select::make('user_id')
                //     ->numeric(),
                TinyEditor::make('case_management_specialty')
                    ->label(__('caseManagement.case_management_specialty'))
                    ->columnSpanFull(),
                TinyEditor::make('nurse_speciality')
                    ->label(__('caseManagement.nurse_speciality'))
                    ->columnSpanFull(),
                TinyEditor::make('paramedic_specialty')
                    ->label(__('caseManagement.paramedic_specialty'))
                    ->columnSpanFull(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                // Tables\Columns\TextColumn::make('physician.name')
                // ->label(__('caseManagement.physician'))
                // //->label(auth()->user()->id)
                // ->numeric()
                //     ->sortable(),
                // Tables\Columns\TextColumn::make('nurse.name')
                //     ->label(__('caseManagement.nurse'))

                //     ->numeric()
                //     ->sortable(),
                // Tables\Columns\TextColumn::make('paramedic.name')
                //     ->label(__('caseManagement.paramedic'))
                //     ->numeric()
                //     ->sortable(),
                Tables\Columns\TextColumn::make('rapid_risk_assessments.name')
                    ->label(__('caseManagement.rapid_risk_assessments'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('clinical_management_advice_and_recommendations.name')
                ->label(__('caseManagement.clinical_management_advice_and_recommendations'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('icp_in_the_care_facility.name')
                    ->label(__('caseManagement.icp_in_the_care_facility'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('monitoring_system.name')
                    ->label(__('caseManagement.monitoring_system'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('determination_of_disease_status.name')
                    ->label(__('caseManagement.determination_of_disease_status'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.created_at')),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.updated_at')),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->label(__('univ.deleted_at'))
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
                //Tables\Actions\CreateRecord::make()
                ])
                ->bulkActions([
                    Tables\Actions\BulkActionGroup::make([
                        Tables\Actions\DeleteBulkAction::make(),
                    ]),
                    ])
                ->emptyStateActions([
                    Tables\Actions\CreateAction::make()
                    
                    //
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListCaseManagement::route('/'),
            // 'create' => Pages\CreateCaseManagement::route('/create'),
            // 'edit' => Pages\EditCaseManagement::route('/{record}/edit'),
        ];
    }    
}
