<?php

namespace App\Filament\Resources;

use App\Filament\Resources\CrecResource\Pages;
use App\Filament\Resources\CrecResource\RelationManagers;
use App\Models\Crec;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class CrecResource extends Resource
{
    protected static ?string $model = Crec::class;

    public static function getModelLabel(): string
    {
        return __('crecs.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    //protected static ?string $navigationLabel = 'Communication sur les risques et engagement communautaire';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('experience_in_health_id')
                    ->label(__('crecs.experience_in_health'))
                    ->relationship('experience_in_health', 'name')
                    ->required(),
                Forms\Components\Select::make('media_environments_id')
                    ->label(__('crecs.media_environments'))
                    ->relationship('media_environments', 'name')
                    ->required(),
                Forms\Components\Select::make('media_comms_content_id')
                    ->label(__('crecs.media_comms_content'))
                    ->relationship('media_comms_content', 'name')
                    ->required(),
                Forms\Components\Select::make('graphic_design_id')
                    ->label(__('crecs.graphic_design'))
                    ->relationship('graphic_design', 'name')
                    ->required(),
                Forms\Components\Select::make('social_media_web_contnet_id')
                    ->label(__('crecs.social_media_web_contnet'))
                    ->relationship('social_media_web_contnet', 'name')
                    ->required(),
                Forms\Components\Select::make('comms_field_deployment_id')
                    ->label(__('crecs.comms_field_deployment'))
                    ->relationship('comms_field_deployment', 'name')
                    ->required(),
                Forms\Components\Select::make('adience_analysis_strategies_id')
                    ->label(__('crecs.adience_analysis_strategies'))
                    ->relationship('adience_analysis_strategies', 'name')
                    ->required(),
                Forms\Components\Select::make('community_engagement_id')
                    ->label(__('crecs.community_engagement'))
                    ->relationship('community_engagement', 'name')
                    ->required(),
                Forms\Components\Select::make('health_education_comms_prog_id')
                    ->label(__('crecs.health_education_comms_prog'))
                    ->relationship('health_education_comms_prog', 'name')
                    ->required(),
                Forms\Components\Select::make('intervener_content_hearing_id')
                    ->label(__('crecs.intervener_content_hearing'))
                    ->relationship('intervener_content_hearing', 'name')
                    ->required(),
                Forms\Components\Select::make('stakeholder_organisation_id')
                    ->label(__('crecs.stakeholder_organisation'))
                    ->relationship('stakeholder_organisation', 'name')
                    ->required(),
                Forms\Components\Select::make('response_risk_responsibility_id')
                    ->label(__('crecs.response_risk_responsibility'))
                    ->relationship('response_risk_responsibility', 'name')
                    ->required(),
                Forms\Components\Select::make('decision_memos_id')
                    ->label(__('crecs.decision_memos'))
                    ->relationship('decision_memos', 'name')
                    ->required(),
                Forms\Components\Select::make('Strategic_communications_planning_id')
                    ->label(__('crecs.Strategic_communications_planning'))
                    ->relationship('Strategic_communications_planning', 'name')
                    ->required(),
                Forms\Components\Select::make('CHES_MCHES_id')
                    ->label(__('crecs.CHES_MCHES'))
                    ->relationship('CHES_MCHES', 'name')
                    ->required(),
                Forms\Components\Select::make('CERC_participation_id')
                    ->label(__('crecs.CERC_participation'))
                    ->relationship('CERC_participation', 'name')
                    ->required(),
                Forms\Components\Select::make('CERC_Trainer_id')
                    ->label(__('crecs.CERC_Trainer'))
                    ->relationship('CERC_Trainer', 'name')
                    ->required(),
                Forms\Components\Select::make('political_Experience_id')
                    ->label(__('crecs.political_Experience'))
                    ->relationship('political_Experience', 'name')
                    ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('experience_in_health.name')
                    ->label(__('crecs.experience_in_health'))
                    ->numeric()
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('media_environments.name')
                    ->label(__('crecs.media_environments'))
                    ->numeric()
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('media_comms_content.name')
                    ->label(__('crecs.media_comms_content'))
                    ->numeric()
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('graphic_design.name')
                    ->label(__('crecs.graphic_design'))
                    ->numeric()
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('social_media_web_contnet.name')
                    ->label(__('crecs.social_media_web_contnet'))
                    ->numeric()
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('comms_field_deployment.name')
                    ->label(__('crecs.comms_field_deployment'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('adience_analysis_strategies.name')
                    ->label(__('crecs.adience_analysis_strategies'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('community_engagement.name')
                    ->label(__('crecs.community_engagement'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('health_education_comms_prog.name')
                    ->label(__('crecs.health_education_comms_prog'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('intervener_content_hearing.name')
                    ->label(__('crecs.intervener_content_hearing'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('stakeholder_organisation.name')
                    ->label(__('crecs.stakeholder_organisation'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('response_risk_responsibility.name')
                    ->label(__('crecs.response_risk_responsibility'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('decision_memos.name')
                    ->label(__('crecs.decision_memos'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_id')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                // Tables\Columns\TextColumn::make('created_at')
                //     ->dateTime()
                //     ->sortable()->searchable()
                //     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('Strategic_communications_planning.name')
                    ->label(__('crecs.Strategic_communications_planning'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('CHES_MCHES.name')
                    ->label(__('crecs.CHES_MCHES'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('CERC_participation.name')
                    ->label(__('crecs.CERC_participation'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('CERC_Trainer.name')
                    ->label(__('crecs.CERC_Trainer'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('political_Experience.name')
                    ->label(__('crecs.political_Experience'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListCrecs::route('/'),
            // 'create' => Pages\CreateCrec::route('/create'),
            // 'edit' => Pages\EditCrec::route('/{record}/edit'),
        ];
    }    
}
