<?php

namespace App\Filament\Resources;

use App\Filament\Resources\DataManagementResource\Pages;
use App\Filament\Resources\DataManagementResource\RelationManagers;
use App\Models\DataManagement;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Mohamedsabil83\FilamentFormsTinyeditor\Components\TinyEditor;

class DataManagementResource extends Resource
{
    protected static ?string $model = DataManagement::class;

    public static function getModelLabel(): string
    {
        return __('dataManagement.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('quantitative_data_id')
                    ->label(__('dataManagement.id'))
                    ->relationship('quantitative_data', 'name')
                    ->required(),
                Forms\Components\Select::make('excel_id')
                ->label(__('dataManagement.excel'))
                    ->relationship('excel', 'name')
                    ->required(),
                Forms\Components\Select::make('access_id')
                ->label(__('dataManagement.access'))
                    ->relationship('access', 'name')
                    ->required(),
                Forms\Components\Select::make('sas_id')
                ->label(__('dataManagement.sas'))
                    ->relationship('sas', 'name')
                    ->required(),
                Forms\Components\Select::make('spss_id')
                ->label(__('dataManagement.spss'))
                    ->relationship('spss', 'name')
                    ->required(),
                Forms\Components\Select::make('status_id')
                ->label(__('dataManagement.status'))
                    ->relationship('status', 'name')
                    ->required(),
                Forms\Components\Select::make('r_id')
                ->label(__('dataManagement.r'))
                    ->relationship('r', 'name')
                    ->required(),
                Forms\Components\Select::make('epi_info_id')
                ->label(__('dataManagement.epi_info'))
                    ->relationship('epi_info', 'name')
                    ->required(),
                Forms\Components\Select::make('monitoring_database_id')
                ->label(__('dataManagement.monitoring_database'))
                    ->relationship('monitoring_database', 'name')
                    ->required(),
                Forms\Components\Select::make('qualitative_data_id')
                ->label(__('dataManagement.qualitative_data'))
                    ->relationship('qualitative_data', 'name')
                    ->required(),
                Forms\Components\Select::make('data_visualization_id')
                ->label(__('dataManagement.data_visualization'))
                    ->relationship('data_visualization', 'name')
                    ->required(),
                Forms\Components\Select::make('geographic_information_system_gis_id')
                ->label(__('dataManagement.geographic_information_system_gis'))
                    ->relationship('geographic_information_system_gis', 'name')
                    ->required(),
                // Forms\Components\TextInput::make('user_id')
                //     ->numeric(),
                TinyEditor::make('please_specify_other_software')
                    ->columnSpanFull(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('quantitative_data.name')
                        ->label(__('dataManagement.id'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('excel.name')
                    ->label(__('dataManagement.excel'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('access.name')
                    ->label(__('dataManagement.access'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('sas.name')
                    ->label(__('dataManagement.sas'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('spss.name')
                    ->label(__('dataManagement.spss'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('status.name')
                    ->label(__('dataManagement.status'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('r.name')
                    ->label(__('dataManagement.r'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('epi_info.name')
                    ->label(__('dataManagement.epi_info'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('monitoring_database.name')
                    ->label(__('dataManagement.monitoring_database'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('qualitative_data.name')
                    ->label(__('dataManagement.qualitative_data'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('data_visualization.name')
                    ->label(__('dataManagement.data_visualization'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('geographic_information_system_gis.name')
                    ->label(__('dataManagement.geographic_information_system_gis'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable(),
                    Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.created_at')),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.updated_at')),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->label(__('univ.deleted_at'))
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListDataManagement::route('/'),
            // 'create' => Pages\CreateDataManagement::route('/create'),
            // 'edit' => Pages\EditDataManagement::route('/{record}/edit'),
        ];
    }    
}
