<?php

namespace App\Filament\Resources\DeploymentOpportunityResource\RelationManagers;

use App\Mail\ApplicationMail;
use App\Models\DeploymentApplication;
use App\Models\DeploymentOpportunity;
use App\Models\User;
use App\Models\UserData;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Notifications\Notification;
use Filament\Resources\RelationManagers\RelationManager;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;

class AdminUserDeploymentApplicationRelationManager extends RelationManager
{
    protected static string $relationship = 'admin_user_deployment_application';

    public function form(Form $form): Form
    {
        return $form
            ->schema([

                Forms\Components\Select::make('status')
                    ->options([
                        'pending' => 'Pending',
                        'Approved' => 'Approved',
                        'Denied' => 'Denied'
                ])
                    //  ->relationship('admin_deployment_application', 'event_name')
                     ->label(__('deploymentApplication.deploymentopportunity'))
                    ->hidden(! auth()->user()->hasAnyRole(['Admin','Deployment_opportunities_creator'])),
                Forms\Components\Hidden::make('id'),
            ]);
    }

    public static function query()
        {
            if (auth()->user()->hasAnyRole('Admin')) {
                return DB::table('deployment_opportunity_user_data');
            } else {
                return DB::table('deployment_opportunity_user_data')->where('user_data_id', auth()->user()->id);
            }
        }

    

    public function table(Table $table): Table
    {
        return $table
      
            ->recordTitleAttribute('id')
            ->columns([
                    Tables\Columns\TextColumn::make('name')
                    ->numeric()
                    ->sortable()
                    ->searchable()
                    ->label('Applicant Name'),
                Tables\Columns\TextColumn::make('status')
                    ->badge()
                    ->colors([
                        'warning' => 'Pending',
                        'success' => 'Approved',
                        'danger' => 'Denied'
                    ]),
                    Tables\Columns\TextColumn::make('user_response')
                    ->badge()
                    ->colors([                        
                        'success' => 'Yes',
                        'danger' => 'no'
                    ])
                    ->label(__('User Response')), 
                
            ])
            ->filters([
                //
            ])
            ->headerActions([
                Tables\Actions\CreateAction::make(),
            ])
            ->actions([
                Tables\Actions\EditAction::make()
                    ->after(function(){
                            $user = auth()->user();
                            $record=$this->ownerRecord;
                            Notification::make()
                                ->title('Application Approval')
                                ->body('Your approval for ' . $record->event_name . ' is '. $record->status . '.')
                                ->sendToDatabase($user); 
                            Mail::to($user->email)->send(new ApplicationMail($record->event_name, $user->name ));                        
 
                            // Find user to send notification to
                            // Notification::make()
                            //     ->success()
                            //     ->title('Application Approval')
                            //     ->icon('heroicon-o-document-text') 
                            //     ->body('Admin has '. $record->status.' for the deployment opportunity '. $record->event_name)
                            //     ->sendToDatabase(User::role('Admin')->get()); 
                    }),
                Tables\Actions\DeleteAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
}
