<?php

namespace App\Filament\Resources;

use App\Filament\Resources\DeploymentResource\Pages;
use App\Filament\Resources\DeploymentResource\RelationManagers;
use App\Models\Deployment;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use App\Models\Country;
use App\Models\State;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class DeploymentResource extends Resource
{
    protected static ?string $model = Deployment::class;

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $modelLabel = 'Deployment History';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\TextInput::make('name')
                    ->label(__('deployments.title'))
                    ->required()
                    ->maxLength(255),
                Forms\Components\Select::make('deployment_diesease_id')
                    ->label(__('deployments.disease'))
                    ->relationship('disease_emergency', 'name')
                    ->required(),
                Forms\Components\Select::make('deployment_role_id')
                    ->label(__('deployments.role'))
                    ->relationship('deployment_role', 'name')
                    ->required(),
                Forms\Components\Radio::make('deployment_type')
                    ->label(__('deployments.type'))
                     ->options([
                        'local' => 'Local Deployment',
                        'international' => 'International Deployment',
                    ])
                    ->required(),
                Forms\Components\DatePicker::make('date_started')
                    ->label(__('qualification.year_started'))
                    ->required(),
                Forms\Components\DatePicker::make('date_completed')
                    ->label(__('qualification.year_completed'))
                    ->required(),
                Forms\Components\Select::make('deployment_country_id')
                        ->label(__('deployments.country'))
                        ->options(Country::all()->pluck('name', 'id')->toArray())
                        ->reactive()
                        ->afterStateUpdated(fn(callable $set) => $set('state_id', null))
                        ->required(),
                    Forms\Components\Select::make('state_id')
                        ->label(__('deployments.state'))
                        ->options(function (callable $get){
                        $country = Country::find($get('deployment_country_id'));
                        if (!$country){
                        return State::all()->pluck('name', 'id');
                        }
                        return $country->states->pluck('name', 'id');
                        })
                        ->reactive()
                       // ->afterStateUpdated(fn(callable $set) => $set('city_id', null))
                        ->required(),
                // Forms\Components\TextInput::make('user_id')
                //     ->numeric(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('name')
                    ->label(__('deployments.title'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('disease_emergency.name')
                    ->label(__('deployments.disease'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('deployment_role.name')
                    ->label(__('deployments.role'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('country.name')
                    ->label(__('deployments.country'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('state.name')
                    ->label(__('deployments.state'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('deployment_type')
                    ->label(__('deployments.type'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('date_started')
                    ->label(__('qualification.year_started'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('date_completed')
                    ->label(__('qualification.year_completed'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user.name')
                    ->label(__('vaccinationation.user'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListDeployments::route('/'),
            'create' => Pages\CreateDeployment::route('/create'),
            'edit' => Pages\EditDeployment::route('/{record}/edit'),
        ];
    }    
}
