<?php

namespace App\Filament\Resources;

use App\Filament\Resources\EmergencyResponseResource\Pages;
use App\Filament\Resources\EmergencyResponseResource\RelationManagers;
use App\Models\EmergencyResponse;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class EmergencyResponseResource extends Resource
{
    protected static ?string $model = EmergencyResponse::class;
    public static function getModelLabel(): string
        {
            return __('emergencyResponse.title');
        }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('domestic_emergency_response_id')
                ->label(__('emergencyResponse.domestic_emergency_response'))
                ->relationship('domestic_emergency_response', 'name')
                ->required(),
                Forms\Components\Select::make('cross_sectoral_id')
                ->label(__('emergencyResponse.cross_sectoral'))
                ->relationship('cross_sectoral', 'name')
                ->required(),
                Forms\Components\Select::make('response_to_international_emergencies_id')
                ->label(__('emergencyResponse.response_to_international_emergencies'))
                ->relationship('response_to_international_emergencies', 'name')
                ->required(),
                Forms\Components\Select::make('eoc_ims_id')
                ->label(__('emergencyResponse.eoc_ims'))
                ->relationship('eoc_ims', 'name')
                ->required(),
                Forms\Components\Select::make('vaccination_campaigns_id')
                ->label(__('emergencyResponse.vaccination_campaigns'))
                ->relationship('vaccination_campaigns', 'name')
                ->required(),
                Forms\Components\Select::make('emergency_leadership_role_id')
                ->label(__('emergencyResponse.emergency_leadership_role'))
                ->relationship('emergency_leadership_role', 'name')
                ->required(),
                Forms\Components\Select::make('multi_sectoral_emergency_response_plans_id')
                ->label(__('emergencyResponse.multi_sectoral_emergency_response_plans'))
                ->relationship('multi_sectoral_emergency_response_plans', 'name')
                ->required(),
                Forms\Components\Select::make('emergency_diseases')
                ->relationship('emergency_diseases', 'name')
                ->label(__('Emergencies/Diseases Responded to'))
                ->multiple()
                ->preload()
                ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('domestic_emergency_response.name')
                    ->label(__('emergencyResponse.domestic_emergency_response'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('cross_sectoral.name')
                    ->label(__('emergencyResponse.cross_sectoral'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('response_to_international_emergencies.name')
                    ->label(__('emergencyResponse.response_to_international_emergencies'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('eoc_ims.name')
                    ->label(__('emergencyResponse.eoc_ims'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('vaccination_campaigns.name')
                    ->label(__('emergencyResponse.vaccination_campaigns'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('emergency_leadership_role.name')
                    ->label(__('emergencyResponse.emergency_leadership_role'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('multi_sectoral_emergency_response_plans.name')
                    ->label(__('emergencyResponse.multi_sectoral_emergency_response_plans'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('emergency_diseases.name')
                    ->label(__('emergencyResponse.emergency_diseases'))
                    ->numeric()
                    ->sortable(),
                    Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListEmergencyResponses::route('/'),
            // 'create' => Pages\CreateEmergencyResponse::route('/create'),
            // 'edit' => Pages\EditEmergencyResponse::route('/{record}/edit'),
        ];
    }    
}
