<?php

namespace App\Filament\Resources;

use App\Filament\Resources\EvaluationResource\Pages;
use App\Filament\Resources\EvaluationResource\RelationManagers;
use App\Models\Evaluation;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

use Mohamedsabil83\FilamentFormsTinyeditor\Components\TinyEditor;

class EvaluationResource extends Resource
{
    protected static ?string $model = Evaluation::class;

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
        protected static ?string $navigationGroup = 'Evaluation';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                // Forms\Components\Select::make('user_id')
                //     ->label(__('evaluation.user'))
                //     ->relationship('user', 'name')
                //     ->required(),
                Forms\Components\Select::make('region_id')
                    ->label(__('evaluation.region_id'))
                    ->relationship('region', 'name')
                    ->required(),
                Forms\Components\Select::make('deployment_opportunity_id')
                    ->label(__('evaluation.region_id'))
                    ->relationship('deployment_opportunity', 'event_name')
                    ->required(),
                Forms\Components\DatePicker::make('date_of_deployment')
                    ->label(__('evaluation.date_of_deployment'))
                    ,
                TinyEditor::make('main_task')
                    ->label(__('evaluation.main_task'))
                    ->columnSpanFull(),
                TinyEditor::make('Positive_aspects')
                    ->label(__('evaluation.Positive_aspects'))
                    ->columnSpanFull(),
                TinyEditor::make('challenging_aspects')
                    ->label(__('evaluation.challenging_aspects'))
                    ->columnSpanFull(),
                Forms\Components\select::make('wellbeing_concerns')
                    ->options([
                            'yes' => 'Yes',
                            'no' => 'No',
                            'other' => 'Other'
                        ])
                    ->label(__('evaluation.wellbeing_concerns'))
                    ,
                TinyEditor::make('other_wellbeing_aspects')
                    ->label(__('evaluation.other_wellbeing_aspects'))
                    ->columnSpanFull(),
                Forms\Components\Select::make('injuries_illness')
                    ->options([
                            'yes' => 'Yes',
                            'no' => 'No',
                        ])
                    ->label(__('evaluation.injuries_illness')),
                TinyEditor::make('describe_illness')
                    ->label(__('evaluation.describe_illness'))
                    ->columnSpanFull(),
                Forms\Components\Select::make('adequate_support')
                    ->label(__('evaluation.adequate_support'))
                    ->options([
                            'yes' => 'Yes',
                            'no' => 'No',
                        ]),
                Forms\Components\Select::make('issue_resolved')
                    ->label(__('evaluation.issue_resolved'))
                    ->options([
                            'yes' => 'Yes',
                            'no' => 'No',
                        ]),
                Forms\Components\TextInput::make('if_not_resolved_provide_details')
                    ->label(__('evaluation.if_not_resolved_provide_details'))
                    ->maxLength(255),
                Forms\Components\Select::make('grade_rrt_support')
                    ->label(__('evaluation.grade_rrt_support'))
                    ->options([
                            'very favorable ' => 'Very favorable',
                            'favorable ' => 'Favorable',
                            'less favorable ' => 'Less favorable',
                            'no support' => 'No support',
                        ]),
                TinyEditor::make('reason_grade_rrt_support')
                    ->label(__('evaluation.reason_grade_rrt_support'))
                    ->columnSpanFull(),
                Forms\Components\Select::make('adequate_training')
                    ->label(__('evaluation.adequate_training'))
                    ->options([
                            'yes' => 'Yes',
                            'no' => 'No',
                        ]),
                TinyEditor::make('reason_adequate_training')
                    ->label(__('evaluation.reason_adequate_training'))
                    ->columnSpanFull(),
                Forms\Components\Select::make('adequate_logistics')
                    ->label(__('evaluation.adequate_logistics'))
                    ->options([
                            'yes' => 'Yes',
                            'no' => 'No',
                        ]),
                TinyEditor::make('reason_reason_adequate_logistics')
                    ->label(__('evaluation.reason_reason_adequate_logistics'))
                    ->columnSpanFull(),
                Forms\Components\Select::make('support_national_response')
                    ->label(__('evaluation.support_national_response'))
                    ->options([
                            'Very useful' => 'Very useful',
                            'Useful' => 'Useful',
                            'Less useful' => 'Less useful',
                            'not useful' => 'Not useful',
                        ]),
                TinyEditor::make('reason_support_national_response')
                    ->label(__('evaluation.reason_support_national_response'))
                    ->columnSpanFull(),
                Forms\Components\Select::make('support_local_intervention')
                    ->label(__('evaluation.support_local_intervention'))
                    ->options([
                            'Very useful' => 'Very useful',
                            'Useful' => 'Useful',
                            'Less useful' => 'Less useful',
                            'not useful' => 'Not useful',
                        ]),
                TinyEditor::make('reason_support_local_intervention')
                    ->label(__('evaluation.reason_support_local_intervention'))
                    ->columnSpanFull(),
                Forms\Components\Select::make('ready_to_deploy_again')
                    ->label(__('evaluation.ready_to_deploy_again'))
                     ->options([
                            'yes' => 'Yes',
                            'no' => 'No',
                        ]),
                TinyEditor::make('reason_ready_to_deploy_again')
                    ->label(__('evaluation.reason_ready_to_deploy_again'))
                    ->columnSpanFull(),
                TinyEditor::make('changes_to_future_deploys')
                    ->label(__('evaluation.changes_to_future_deploys'))
                    ->columnSpanFull(),
                TinyEditor::make('additional_comments')
                    ->label(__('evaluation.additional_comments'))
                    ->columnSpanFull(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable()
                    ->hidden(! auth()->user()->hasAnyRole('Admin')),
                Tables\Columns\TextColumn::make('deployment_opportunity.event_name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('region.name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('date_of_deployment')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('wellbeing_concerns')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('injuries_illness')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('adequate_support')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('issue_resolved')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('if_not_resolved_provide_details')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('grade_rrt_support')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('adequate_training')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('adequate_logistics')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('support_national_response')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('support_local_intervention')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('ready_to_deploy_again')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable(),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListEvaluations::route('/'),
            'create' => Pages\CreateEvaluation::route('/create'),
            'edit' => Pages\EditEvaluation::route('/{record}/edit'),
        ];
    }    
}
