<?php

namespace App\Filament\Resources;

use App\Filament\Resources\LaboratoryExperienceResource\Pages;
use App\Filament\Resources\LaboratoryExperienceResource\RelationManagers;
use App\Models\LaboratoryExperience;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Filament\Forms\Components\CheckboxList;


class LaboratoryExperienceResource extends Resource
{
    protected static ?string $model = LaboratoryExperience::class;

    public static function getModelLabel(): string
    {
        return __('laboratoryExperience.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('biosafety_experience_id')
                    ->label(__('laboratoryExperience.biosafety_experience'))
                    ->relationship('biosafety_experience', 'name')
                    ->required(),
                Forms\Components\Select::make('laboratory_quality_management_id')
                    ->label(__('laboratoryExperience.laboratory_quality_management'))
                    ->relationship('laboratory_quality_management', 'name')
                    ->required(),
                Forms\Components\Select::make('sample_reception_and_acquisition_id')
                    ->label(__('laboratoryExperience.sample_reception_and_acquisition'))
                    ->relationship('sample_reception_and_acquisition', 'name')
                    ->required(),
                    Forms\Components\Select::make('test_type_id')
                    ->relationship('test_type', 'name')
                    ->preload()
                    ->multiple(),
                Forms\Components\Select::make('sample_transport_id')
                    ->label(__('laboratoryExperience.sample_transport'))
                    ->relationship('sample_transport', 'name')
                    ->required(),
                Forms\Components\Select::make('antimicrobial_id')
                    ->label(__('laboratoryExperience.antimicrobial'))
                    ->relationship('antimicrobial', 'name')
                    ->required(),
                Forms\Components\Select::make('parasitology_id')
                    ->label(__('laboratoryExperience.parasitology'))
                    ->relationship('parasitology', 'name')
                    ->required(),
                Forms\Components\Select::make('mycology_id')
                    ->label(__('laboratoryExperience.mycology'))
                    ->relationship('mycology', 'name')
                    ->required(),
                Forms\Components\Select::make('clinical_chemistry_id')
                    ->label(__('laboratoryExperience.clinical_chemistry'))
                    ->relationship('clinical_chemistry', 'name')
                    ->required(),
                Forms\Components\Select::make('blood_bank_id')
                    ->label(__('laboratoryExperience.blood_bank'))
                    ->relationship('blood_bank', 'name')
                    ->required(),
                Forms\Components\Select::make('molecular_methods_id')
                    ->label(__('laboratoryExperience.molecular_methods'))
                    ->relationship('molecular_methods', 'name')
                    ->required(),
                Forms\Components\Select::make('advanced_molecular_detection_dma_id')
                    ->label(__('laboratoryExperience.advanced_molecular_detection_dma'))
                    ->relationship('advanced_molecular_detection_dma', 'name')
                    ->required(),
                Forms\Components\Select::make('viral_culture_id')
                    ->label(__('laboratoryExperience.viral_culture'))
                    ->relationship('viral_culture', 'name')
                    ->required(),
                Forms\Components\Select::make('serology_id')
                    ->label(__('laboratoryExperience.serology'))
                    ->relationship('serology', 'name')
                    ->required(),
                Forms\Components\Select::make('bsl_3_id')
                    ->label(__('laboratoryExperienec.bsl_3'))
                    ->relationship('bsl_3', 'name')
                    ->required(),
                Forms\Components\Select::make('bacterial_culture_id')
                    ->label(__('laboratoryExperience.bacterial_culture'))
                    ->relationship('bacterial_culture', 'name')
                    ->required(),
                Forms\Components\Select::make('phlebotomy_venipuncture_id')
                    ->label(__('laboratoryExperience.phlebotomy_venipuncture'))
                    ->relationship('phlebotomy_venipuncture', 'name')
                    ->required(),
                Forms\Components\Select::make('laboratory_training_instructor_id')
                    ->label(__('laboratoryExperience.laboratory_training_instructor'))
                    ->relationship('laboratory_training_instructor', 'name')
                    ->required(),
                Forms\Components\Select::make('laboratory_supervisor_experience_id')
                    ->label(__('laboratoryExperience.laboratory_supervisor_experience'))
                    ->relationship('laboratory_supervisor_experience', 'name')
                    ->required(),
                Forms\Components\Select::make('laboratory_field_intervention_coordinator_id')
                    ->label(__('laboratoryExperience.laboratory_field_intervention_coordinator'))
                    ->relationship('laboratory_field_intervention_coordinator', 'name')
                    ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                
                Tables\Columns\TextColumn::make('biosafety_experience.name')
                    ->label(__('laboratoryExperience.biosafety_experience'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('laboratory_quality_management.name')
                    ->label(__('laboratoryExperience.laboratory_quality_management'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('sample_reception_and_acquisition.name')
                    ->label(__('laboratoryExperience.sample_reception_and_acquisition'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('sample_transport.name')
                    ->label(__('laboratoryExperience.sample_transport'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('antimicrobial.name')
                    ->label(__('laboratoryExperience.antimicrobial'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('parasitology.name')
                    ->label(__('laboratoryExperience.parasitology'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('mycology.name')
                    ->label(__('laboratoryExperience.mycology'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('clinical_chemistry.name')
                    ->label(__('laboratoryExperience.clinical_chemistry'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('blood_bank.name')
                    ->label(__('laboratoryExperience.blood_bank'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('molecular_methods.name')
                    ->label(__('laboratoryExperience.molecular_methods'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('advanced_molecular_detection_dma.name')
                    ->label(__('laboratoryExperience.advanced_molecular_detection_dma'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('viral_culture.name')
                    ->label(__('laboratoryExperience.viral_culture'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('serology.name')
                    ->label(__('laboratoryExperience.serology'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('bsl_3.name')
                    ->label(__('laboratoryExperienec.bsl_3'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('bacterial_culture.name')
                    ->label(__('laboratoryExperience.bacterial_culture'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('phlebotomy_venipuncture.name')
                    ->label(__('laboratoryExperience.phlebotomy_venipuncture'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('laboratory_training_instructor.name')
                    ->label(__('laboratoryExperience.laboratory_training_instructor'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('laboratory_supervisor_experience.name')
                    ->label(__('laboratoryExperience.laboratory_supervisor_experience'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('laboratory_field_intervention_coordinator.name')
                    ->label(__('laboratoryExperience.laboratory_field_intervention_coordinator'))
                    ->numeric()
                    ->sortable(),
                    Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListLaboratoryExperiences::route('/'),
            // 'create' => Pages\CreateLaboratoryExperience::route('/create'),
            // 'edit' => Pages\EditLaboratoryExperience::route('/{record}/edit'),
        ];
    }    
}
