<?php

namespace App\Filament\Resources;

use App\Filament\Resources\MemberEvaluationResource\Pages;
use App\Filament\Resources\MemberEvaluationResource\RelationManagers;
use App\Models\MemberEvaluation;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Mohamedsabil83\FilamentFormsTinyeditor\Components\TinyEditor;
class MemberEvaluationResource extends Resource
{
    protected static ?string $model = MemberEvaluation::class;

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
     protected static ?string $navigationGroup = 'Evaluation';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                 Forms\Components\Select::make('user_id')
                    ->label(__('member_evaluation.user'))
                    ->relationship('user', 'name')
                    ->required(),
                     Forms\Components\Select::make('deployment_opportunity_id')
                    ->label(__('member_evaluation.opportunity'))
                    ->relationship('deployment_opportunity', 'event_name')
                    ->required(),
                Forms\Components\Select::make('rrt_member_satisfaction')
                    ->label(__('member_evaluation.rrt_member_satisfaction'))
                    ->options([
                            'Very satisfied' => 'Very satisfied',
                            'Satisfied' => 'Satisfied',
                            'Less satisfied' => 'Less satisfied',
                            'Not satisfied' => 'Not satisfied',
                        ]),
                Forms\Components\Select::make('rrt_member_communication_satisfaction')
                    ->label(__('member_evaluation.rrt_member_communication_satisfaction'))
                    ->options([
                            'Very satisfied' => 'Very satisfied',
                            'Satisfied' => 'Satisfied',
                            'Less satisfied' => 'Less satisfied',
                            'Not satisfied' => 'Not satisfied',
                        ]),
                Forms\Components\TextInput::make('goals_target')
                    ->label(__('member_evaluation.goals_target'))
                    ->numeric(),
                Forms\Components\TextInput::make('goals_achievement')
                    
                    ->label(__('member_evaluation.goals_achievement'))->numeric(),
                Forms\Components\TextInput::make('objectives_changes')
                    
                    ->label(__('member_evaluation.objectives_changes'))->maxLength(255),
                TinyEditor::make('factors_of_members_success')
                    
                    ->label(__('member_evaluation.factors_of_members_success'))->columnSpanFull(),
                TinyEditor::make('factors_of_members_failure')
                    
                    ->label(__('member_evaluation.factors_of_members_failure'))->columnSpanFull(),
                Forms\Components\TextInput::make('number_of_activities_set')
                    
                    ->label(__('member_evaluation.number_of_activities_set'))->numeric(),
                Forms\Components\TextInput::make('number_of_activities_achieved')
                    
                    ->label(__('member_evaluation.number_of_activities_achieved'))->numeric(),
                TinyEditor::make('changes_to_activities')
                    
                    ->label(__('member_evaluation.changes_to_activities'))->columnSpanFull(),
                TinyEditor::make('factors_of_activities_success_member')
                    
                    ->label(__('member_evaluation.factors_of_activities_success_member'))->columnSpanFull(),
                TinyEditor::make('factors_of_activities_failure_member')
                    
                    ->label(__('member_evaluation.factors_of_activities_failure_member'))->columnSpanFull(),
                Forms\Components\TextInput::make('number_of_deliverables_set')
                    
                    ->label(__('member_evaluation.number_of_deliverables_set'))->numeric(),
                Forms\Components\TextInput::make('number_of_deliverables_achieved')
                    
                    ->label(__('member_evaluation.number_of_deliverables_achieved'))->numeric(),
                TinyEditor::make('changes_to_deliverables')
                    
                    ->label(__('member_evaluation.changes_to_deliverables'))->columnSpanFull(),
                TinyEditor::make('factors_of_deliverables_success_member')
                    
                    ->label(__('member_evaluation.factors_of_deliverables_success_member'))->columnSpanFull(),
                TinyEditor::make('factors_of_deliverables_failure_member')
                    
                    ->label(__('member_evaluation.factors_of_deliverables_failure_member'))->columnSpanFull(),
                Forms\Components\TextInput::make('number_of_indicators_measures_set')
                    
                    ->label(__('member_evaluation.number_of_indicators_measures_set'))->numeric(),
                Forms\Components\TextInput::make('number_of_indicators_measures_achieved')
                    
                    ->label(__('member_evaluation.number_of_indicators_measures_achieved'))->numeric(),
                TinyEditor::make('changes_to_indicators_measures')
                    
                    ->label(__('member_evaluation.changes_to_indicators_measures'))->columnSpanFull(),
                TinyEditor::make('factors_of_indicators_measures_success_member')
                    
                    ->label(__('member_evaluation.factors_of_indicators_measures_success_member'))->columnSpanFull(),
                TinyEditor::make('factors_of_indicators_measures_failure_member')
                    
                    ->label(__('member_evaluation.factors_of_indicators_measures_failure_member'))->columnSpanFull(),
                TinyEditor::make('comments_on_failure')
                    
                    ->label(__('member_evaluation.comments_on_failure'))->columnSpanFull(),
                TinyEditor::make('how_can_RRT_help_the_member')
                    
                    ->label(__('member_evaluation.how_can_RRT_help_the_member'))->columnSpanFull(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('deployment_opportunity.event_name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('rrt_member_satisfaction')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('rrt_member_communication_satisfaction')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('goals_target')
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('goals_achievement')
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('objectives_changes')
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('number_of_activities_set')
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('number_of_activities_achieved')
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('number_of_deliverables_set')
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('number_of_deliverables_achieved')
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('number_of_indicators_measures_set')
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('number_of_indicators_measures_achieved')
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ,
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListMemberEvaluations::route('/'),
            'create' => Pages\CreateMemberEvaluation::route('/create'),
            'edit' => Pages\EditMemberEvaluation::route('/{record}/edit'),
        ];
    }    
}
