<?php

namespace App\Filament\Resources;

use App\Filament\Resources\PsychosocialExperienceResource\Pages;
use App\Filament\Resources\PsychosocialExperienceResource\RelationManagers;
use App\Models\PsychosocialExperience;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class PsychosocialExperienceResource extends Resource
{
    protected static ?string $model = PsychosocialExperience::class;
    public static function getModelLabel(): string
    {
        return __('psychosocialExperience.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                // Forms\Components\TextInput::make('psychosocial_experience_id')
                //     ->numeric(),
                Forms\Components\Select::make('licensee_id')
                    ->label(__('psychosocialExperience.licensee'))
                    ->relationship('licensee', 'name')
                    ->required()
                    ->label(__('fields.name')),
                Forms\Components\Select::make('psychiatrist_id')
                    ->label(__('psychosocialExperience.psychiatrist'))
                    ->relationship('psychiatrist', 'name')
                    ->required(),
                Forms\Components\Select::make('advisor_id')
                    ->label(__('psychosocialExperience.advisor'))
                    ->relationship('advisor', 'name')
                    ->required(),
                Forms\Components\Select::make('social_worker_id')
                    ->label(__('psychosocialExperience.social_worker'))
                    ->relationship('social_worker', 'name')
                    ->required(),
                Forms\Components\Select::make('trauma_based_therapy_id')
                    ->label(__('psychosocialExperience.trauma_based_therapy'))
                    ->relationship('trauma_based_therapy', 'name')
                    ->required(),
                Forms\Components\Select::make('cognitive_behavioural_therapy_id')
                    ->label(__('psychosocialExperience.cognitive_behavioural_therapy'))
                    ->relationship('cognitive_behavioural_therapy', 'name')
                    ->required(),
                Forms\Components\Select::make('psychodynamic_therapy_id')
                    ->label(__('psychosocialExperience.psychodynamic_therapy'))
                    ->relationship('psychodynamic_therapy', 'name')
                    ->required(),
                Forms\Components\Select::make('psychoanalytic_therapy_id')
                    ->label(__('psychosocialExperience.psychoanalytic_therapy'))
                    ->relationship('psychoanalytic_therapy', 'name')
                    ->required(),
                Forms\Components\Select::make('integrative_or_holistic_therapy_id')
                    ->label(__('psychosocialExperience.integrative_or_holistic_therapy'))
                    ->relationship('integrative_or_holistic_therapy', 'name')
                    ->required(),
                Forms\Components\Select::make('humanistic_therapy_id')
                    ->label(__('psychosocialExperience.humanistic_therapy'))
                    ->relationship('humanistic_therapy', 'name')
                    ->required(),
                Forms\Components\Select::make('pediatric_therapy_id')
                    ->label(__('psychosocialExperience.pediatric_therapy'))
                    ->relationship('pediatric_therapy', 'name')
                    ->required(),
                // Forms\Components\Select::make('user_id')
                //     ->relationship('user', 'name')
                //     ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('id')
                    ->numeric()
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('licensee.name')
                    ->label(__('psychosocialExperience.licensee'))
                    ->sortable()->searchable(),
                 Tables\Columns\TextColumn::make('psychiatrist.name')
                    ->label(__('psychosocialExperience.psychiatrist'))
                    ->numeric()
                    ->sortable()->searchable(),
                 Tables\Columns\TextColumn::make('advisor.name')
                    ->label(__('psychosocialExperience.advisor'))
                    ->numeric()
                    ->sortable()->searchable(),
                 Tables\Columns\TextColumn::make('social_worker.name')
                    ->label(__('psychosocialExperience.social_worker'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('trauma_based_therapy.name')
                    ->label(__('psychosocialExperience.trauma_based_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('cognitive_behavioural_therapy.name')
                    ->label(__('psychosocialExperience.cognitive_behavioural_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('psychodynamic_therapy.name')
                    ->label(__('psychosocialExperience.psychodynamic_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('psychoanalytic_therapy.name')
                    ->label(__('psychosocialExperience.psychoanalytic_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('integrative_or_holistic_therapy.name')
                    ->label(__('psychosocialExperience.integrative_or_holistic_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('humanistic_therapy.name')
                    ->label(__('psychosocialExperience.humanistic_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('pediatric_therapy.name')
                    ->label(__('psychosocialExperience.pediatric_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()->searchable()
                    
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListPsychosocialExperiences::route('/'),
            // 'create' => Pages\CreatePsychosocialExperience::route('/create'),
            // 'edit' => Pages\EditPsychosocialExperience::route('/{record}/edit'),
        ];
    }    
}
