<?php

namespace App\Filament\Resources;

use App\Filament\Resources\ReadinessAndRtMemberResource\Pages;
use App\Filament\Resources\ReadinessAndRtMemberResource\RelationManagers;
use App\Models\ReadinessAndRtMember;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Filament\Forms\Components\Section;
use Filament\Forms\Components\FileUpload;
use Filament\Forms\Components\SpatieMediaLibraryFileUpload;

use Filament\Infolists;
use Filament\Infolists\Infolist;





class ReadinessAndRtMemberResource extends Resource
{
    public static function getModelLabel(): string
    {
        return __('readinessAndRtMember.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                //     ->numeric(),
                Section::make('First Training')
                    ->description('Optional')
                    ->columns([
                        'sm' => 3,
                    ])
                    ->schema([   
                        Forms\Components\Select::make('training_1_id')
                        ->label(__('readinessAndRtMember.training_1'))
                            ->relationship('training_1', 'name'),
                        Forms\Components\DatePicker::make('training_1_date')
                        ->label(__('readinessAndRtMember.training_1_start_date')),
                        Forms\Components\DatePicker::make('training_1_expiration_date')
                        ->label(__('readinessAndRtMember.expiration_date')), 
                    ]),
                Section::make('Second Training')
                    ->description('Optional')
                    ->columns([
                        'sm' => 3,
                    ])
                    ->schema([   
                        Forms\Components\Select::make('training_2_id')
                        ->label(__('readinessAndRtMember.training_2'))
                            ->relationship('training_2', 'name'), 
                        Forms\Components\DatePicker::make('training_2_date')
                        ->label(__('readinessAndRtMember.training_2_start_date')),
                        Forms\Components\DatePicker::make('training_2_expiration_date')
                        ->label(__('readinessAndRtMember.expiration_date')), 
                    ]),
                Section::make('Third Training')
                    ->description('Optional')
                    ->columns([
                        'sm' => 3,
                    ])
                    ->schema([ 
                        Forms\Components\Select::make('trainings_3_id')
                        ->label(__('readinessAndRtMember.trainings_3'))
                            ->relationship('trainings_3', 'name'),
                        Forms\Components\DatePicker::make('training_3_date')
                        ->label(__('readinessAndRtMember.training_3_start_date')),
                        Forms\Components\DatePicker::make('training_3_expiration_date')
                        ->label(__('readinessAndRtMember.expiration_date')),
                    ]),
                Section::make('Fourth Training')
                    ->description('Optional')
                    ->columns([
                        'sm' => 3,
                    ])
                    ->schema([ 
                        Forms\Components\Select::make('training_4_id')
                        ->label(__('readinessAndRtMember.training_4'))
                            ->relationship('training_4', 'name'),
                        Forms\Components\DatePicker::make('training_4_date')
                        ->label(__('readinessAndRtMember.training_4_start_date')),
                        Forms\Components\DatePicker::make('training_4_expiration_date')
                        ->label(__('readinessAndRtMember.expiration_date')),
                    ]),
                Section::make('Uploads')
                     ->description('These are uploads will prove that you are medically and phyisically fit for the RRT deployment and shouold not be confused with Academic Qualifications')
                     ->columns([
                        'sm' => 2,
                    ])
                    ->schema([
                        FileUpload::make('upload_certified_rrt_training')
                        ->label(__('readinessAndRtMember.upload_certified_rrt_training'))
                        ->downloadable()
                        ->previewable(true),
                        FileUpload::make('upload_medical_certificate')
                        ->label(__('readinessAndRtMember.upload_medical_certificate'))
                        ->downloadable()
                        ->previewable(true),
                        FileUpload::make('upload_certificate_of_physical_fitness')
                        ->label(__('readinessAndRtMember.upload_certificate_of_physical_fitness'))
                        ->downloadable()
                        ->previewable(true),
                        FileUpload::make('training_support_documents')
                        ->label(__('readinessAndRtMember.training_support_documents'))
                        ->downloadable()
                        ->previewable(true)
                        ->multiple()
                    ])
  
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                // Tables\Columns\TextColumn::make('user_id')
                //     ->numeric()
                //     ->sortable(),
                Tables\Columns\TextColumn::make('user.name')
                    ->label(__('univ.user'))
                    ->numeric()
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('training_1.name')
                ->label(__('readinessAndRtMember.training_1'))
                    ->sortable(),
                 Tables\Columns\TextColumn::make('training_1_date')
                 ->label(__('readinessAndRtMember.training_1_start_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('training_1_expiration_date')
                ->label(__('readinessAndRtMember.training_1_expiration_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('training_2.name')
                ->label(__('readinessAndRtMember.training_2'))
                    ->sortable(),
                      Tables\Columns\TextColumn::make('training_2_date')
                      ->label(__('readinessAndRtMember.training_2_start_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('training_2_expiration_date')
                ->label(__('readinessAndRtMember.training_2_expiration_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('trainings_3.name')
                ->label(__('readinessAndRtMember.trainings_3'))
                    ->sortable()->sortable()->searchable(),
               Tables\Columns\TextColumn::make('training_3_date')
               ->label(__('readinessAndRtMember.training_3_start_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('training_3_expiration_date')
                ->label(__('readinessAndRtMember.training_3_expiration_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                     Tables\Columns\TextColumn::make('training_4.name')
                     ->label(__('readinessAndRtMember.training_4'))
                    ->sortable()->sortable()->searchable(),
                Tables\Columns\TextColumn::make('training_4_date')
                ->label(__('readinessAndRtMember.training_4_start_date'))
                    ->date()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('training_4_expiration_date')
                ->label(__('readinessAndRtMember.training_4_expiration_date'))
                    ->date()
                    
                    ->sortable()
                     ->toggleable(isToggledHiddenByDefault: true),
                
                Tables\Columns\TextColumn::make('created_at')
                     ->dateTime()
                     ->sortable()
                     ->toggleable(isToggledHiddenByDefault: true)
                     ->label(__('univ.created_at')),
                 Tables\Columns\TextColumn::make('updated_at')
                     ->dateTime()
                     ->sortable()
                     ->toggleable(isToggledHiddenByDefault: true)
                     ->label(__('univ.updated_at')),
                 Tables\Columns\TextColumn::make('deleted_at')
                     ->dateTime()
                     ->sortable()
                     ->label(__('univ.deleted_at'))
                     ->toggleable(isToggledHiddenByDefault: true),
//Tables\Columns\TextColumn::make('upload_certified_rrt_training')
                 
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
                Tables\Actions\ViewAction::make(),
                // Tables\Actions\Action::make(name: 'Promote') 
                // ->action(function (ReadinessAndRtMember $record) {
                
                // //dump($record);
                // }),
                
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }

//     public static function infolist(Infolist $infolist): Infolist
// {
//     return $infolist
//         ->schema([
//                // Section::make('Training 1 Section')
//                 //->schema([
//                     Infolists\Components\TextEntry::make('training_1.name'),
//                     Infolists\Components\TextEntry::make('training_1_date'),
//                     Infolists\Components\TextEntry::make('training_1_expiration_date'),
//                //]),
//                 Infolists\Components\TextEntry::make('training_2.name'),
//                 Infolists\Components\TextEntry::make('training_2_date'),
//                 Infolists\Components\TextEntry::make('training_2_expiration_date'),
//                 Infolists\Components\TextEntry::make('trainings_3.name'),
//                Infolists\Components\TextEntry::make('training_3_date'),
//                 Infolists\Components\TextEntry::make('training_3_expiration_date'),
//                 Infolists\Components\TextEntry::make('training_4.name'),
//                 Infolists\Components\TextEntry::make('training_4_date'),
//                 Infolists\Components\TextEntry::make('training_4_expiration_date'),
//                 Infolists\Components\TextEntry::make('upload_certified_rrt_training'),
//                 Infolists\Components\TextEntry::make('upload_medical_certificate'),
//                 Infolists\Components\TextEntry::make('upload_certificate_of_physical_fitness'),
//                 Infolists\Components\TextEntry::make('training_support_documents'),
//                 Infolists\Components\TextEntry::make('user.name'),
//                 Infolists\Components\TextEntry::make('created_at'),
//                 Infolists\Components\TextEntry::make('updated_at'),
//                 Infolists\Components\TextEntry::make('deleted_at')
                
//                 ->columnSpan(3),
//         ]);
//}
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListReadinessAndRtMembers::route('/'),
            // 'create' => Pages\CreateReadinessAndRtMember::route('/create'),
            // 'edit' => Pages\EditReadinessAndRtMember::route('/{record}/edit'),
             'View' => Pages\ViewRRT_record::route('/{record}'),
        ];
    }    
}
