<?php

namespace App\Filament\Resources;

use App\Filament\Resources\RegisterResource\Pages;
use App\Filament\Resources\RegisterResource\RelationManagers;
use App\Models\Register;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Filament\Forms\Components\Section;

use Mohamedsabil83\FilamentFormsTinyeditor\Components\TinyEditor;

class RegisterResource extends Resource
{
    protected static ?string $model = Register::class;
    public static function getModelLabel(): string
    {
        return __('register.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    


    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('agency_structure_id')
                    ->label(__('register.structure_of_agency'))
                    ->relationship('agency_structure', 'name')
                    ->required(),
                Forms\Components\Select::make('profession_id')
                    ->label(__('register.profession'))
                    ->relationship('profession', 'name')
                    ->required(),
                     Forms\Components\Radio::make('deployment_type')
                    ->label(__('register.gender'))
                     ->options([
                        'male' => 'Male',
                        'female' => 'Female',
                    ]),
                Forms\Components\TextInput::make('national_id_number')
                    ->label(__('register.idnum'))
                    ->required()
                    ->maxLength(255),
                Forms\Components\TextInput::make('service_number')
                    ->label(__('register.service'))
                    ->required()
                    ->maxLength(255),
                Forms\Components\Select::make('nationality_id')
                    ->label(__('register.nationality'))
                    ->relationship('nationality', 'name')
                    ->required(),
                Forms\Components\Select::make('department_id')
                    ->label(__('register.department'))
                    ->relationship('department', 'name')
                    ->required(),
                Forms\Components\TextInput::make('name_of_supervisory_line_manager')
                ->label(__('register.name_of_supervisory_line_manager'))
                    //->required()
                    ->maxLength(255),
                Forms\Components\TextInput::make('supervisorr_email')
                ->label(__('register.supervisorr_email'))
                    ->email()
                    //->required()
                    ->maxLength(255),
                Forms\Components\Radio::make('fetp_mmber')
                ->label(__('register.fetp_mmber'))
                    ->options([
                        'Yes' => 'Yes',
                        'No' => 'No',
                    ])
                    ->required(),
                Forms\Components\Radio::make('fetp_graduate')
                ->label(__('register.fetp_graduate'))
                    ->options([
                        'Yes' => 'Yes',
                        'No' => 'No',
                    ])
                    ->required(),
                Forms\Components\TextInput::make('city_of_residence')
                ->label(__('register.city_of_residence'))
                    ->required()
                    ->maxLength(255),
                TinyEditor::make('workplace')
                ->label(__('register.workplace'))
                    ->required()
                    ->columnSpanFull(),
                Forms\Components\TextInput::make('phone_number')
                ->label(__('register.phone_number'))
                    ->tel()
                    ->telRegex('/^[+]*[(]{0,1}[0-9]{1,4}[)]{0,1}[-\s\.\/0-9]*$/')
                    ->maxLength(255)
                    ->required(),
                Forms\Components\TextInput::make('email_address')
                ->label(__('register.email_address'))
                    ->email()
                    ->maxLength(255)
                    ->required(),
                Forms\Components\Select::make('national_agency_employee')
                ->label(__('register.national_agency_employee'))
                    ->options([
                            'Yes' => 'Yes',
                            'No' => 'No',
                        ])
                        ->required(),
                Section::make('Public Health Experience in DRC')
                    ->schema([
                    Forms\Components\Radio::make('public_health_experience_drc')
                    ->label(__('register.public_health_experience_drc'))
                        ->options([
                            'Yes' => 'Yes',
                            'No' => 'No',
                        ])
                        ->required(),
                    Forms\Components\TextInput::make('if_yes_number')
                    ->label(__('register.if_yes_number'))
                        ->numeric(),
                ]),
                Section::make('EOC Experience')
                    ->schema([
                        Forms\Components\Radio::make('eoc_experience')
                        ->label(__('register.eoc_experience'))
                            ->options([
                            'Yes' => 'Yes',
                            'No' => 'No',
                        ])
                        ->required(),
                        Forms\Components\TextInput::make('eoc_if_yes_number_of_years')
                        ->label(__('register.eoc_if_yes_number_of_years'))
                            ->numeric(),
                ]),
                 Section::make('International Work')
                    // ->description('Description')
                    ->schema([       
                        Forms\Components\Radio::make('international_work_experience_no_study_abroad')
                        ->label(__('register.international_work_experience_no_study_abroad'))
                            ->options([
                            'Yes' => 'Yes',
                            'No' => 'No',
                        ])
                        ->required(),
                        Forms\Components\TextInput::make('number_international_deployments')
                        ->label(__('register.number_international_deployments'))
                            ->numeric(),
                    ]),
                  Section::make('Team Leader Experience')
                    // ->description('Description')
                    ->schema([   
                        Forms\Components\Radio::make('experience_as_a_team_leader')
                        ->label(__('register.experience_as_a_team_leader'))
                            ->options([
                            'Yes' => 'Yes',
                            'No' => 'No',
                        ])
                        ->required(),
                        Forms\Components\TextInput::make('if_yes_above_number_of_deployments_as_tl')
                        ->label(__('register.if_yes_above_number_of_deployments_as_tl'))
                            ->numeric(),
                    ]),
                Forms\Components\Select::make('country_residence_id')
                    ->label(__('register.country_residence'))
                     ->relationship('country_residence', 'name')
                    ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
             Tables\Columns\TextColumn::make('user.name')
                ->label(__('univ.user'))
                    ->numeric()
                    ->sortable()
                    ->visible(fn () => auth()->user()->hasAnyRole('Admin')),
                Tables\Columns\TextColumn::make('agency_structure.name')
                ->label(__('register.structure_of_agency'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('department.name')
                ->label(__('register.department'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('profession.name')
                ->label(__('register.profession'))
                    ->searchable(),
                    //->hiddenFrom('md'),
                Tables\Columns\TextColumn::make('name_of_supervisory_line_manager')
                ->label(__('register.name_of_supervisory_line_manager'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('supervisorr_email')
                ->label(__('register.supervisorr_email'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('fetp_mmber')
                ->label(__('register.fetp_mmber'))
                    ->searchable() 
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('fetp_graduate')
                ->label(__('register.fetp_graduate'))
                    ->searchable() 
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('city_of_residence')
                ->label(__('register.city_of_residence')),
                Tables\Columns\TextColumn::make('phone_number')
                ->label(__('register.phone_number'))
                    ->searchable() 
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('email_address')
                ->label(__('register.phone_number'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('national_agency_employee')
                ->label(__('register.email_address'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('public_health_experience_drc')
                ->label(__('register.national_agency_employee'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('if_yes_number')
                ->label(__('register.public_health_experience_drc'))
                    ->numeric()
                    ->sortable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('eoc_experience')
                ->label(__('register.if_yes_number'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('eoc_if_yes_number_of_years')
                ->label(__('register.eoc_experience'))
                    ->numeric()
                    ->sortable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('international_work_experience_no_study_abroad')
                ->label(__('register.eoc_if_yes_number_of_years'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('number_international_deployments')
                ->label(__('register.international_work_experience_no_study_abroad'))
                    ->numeric()
                    ->sortable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('experience_as_a_team_leader')
                ->label(__('register.number_international_deployments'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('if_yes_above_number_of_deployments_as_tl')
                ->label(__('register.exprience_as_a_team_leader'))
                    ->numeric()
                    ->sortable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('country_residence.name')
                ->label(__('register.if_yes_above_number_of_deployments_as_tl'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                // Tables\Columns\TextColumn::make('qualification_id')
                //     ->numeric()
                //     ->sortable(),
               
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListRegisters::route('/'),
            // 'create' => Pages\CreateRegister::route('/create'),
            // 'edit' => Pages\EditRegister::route('/{record}/edit'),
        ];
    }    
}
