<?php

namespace App\Filament\Resources;

use App\Filament\Resources\SecurityManagerExperienceResource\Pages;
use App\Filament\Resources\SecurityManagerExperienceResource\RelationManagers;
use App\Models\SecurityManagerExperience;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class SecurityManagerExperienceResource extends Resource
{
    protected static ?string $model = SecurityManagerExperience::class;
    public static function getModelLabel(): string
    {
        return __('securityManager.title');
    }


    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('occupational_health_and_safety_assessment_id')
                ->label(__('securityManager.occupational_health_and_safety_assessment'))
                    ->relationship('occupational_health_and_safety_assessment', 'name')
                    ->required(),
                Forms\Components\Select::make('osh_y_n_facility_assessment_id')
                ->label(__('securityManager.osh_y_n_facility_assessment'))
                    ->relationship('osh_y_n_facility_assessment', 'name')
                    ->required(),
                Forms\Components\Select::make('development_of_an_incident_action_id')
                ->label(__('securityManager.development_of_an_incident_action'))
                    ->relationship('development_of_an_incident_action', 'name')
                    ->required(),
                Forms\Components\Select::make('other_training_on_osh_id')
                ->label(__('securityManager.other_training_on_osh'))
                    ->relationship('other_training_on_osh', 'name')
                    ->required(),
                Forms\Components\Select::make('training_received_in_the_field_of_expertise_id')
                ->label(__('securityManager.training_received_in_the_field_of_expertise'))
                    ->relationship('training_received_in_the_field_of_expertise', 'name')
                    ->required(),
                Forms\Components\Radio::make('do_you_have_a_service_passport')
                ->label(__('securityManager.do_you_have_a_service_passport'))
                     ->options([
                        'Yes' => 'Yes',
                        'No' => 'No',
                    ]),
                Forms\Components\Radio::make('eir_volunteer')
                ->label(__('securityManager.eir_volunteer'))
                     ->options([
                        'Yes' => 'Yes',
                        'No' => 'No',
                     ]),
                Forms\Components\Select::make('national_training_insert_name_and_date_of_just_in_time')
                ->label(__('securityManager.national_training_insert_name_and_date_of_just_in_time'))
                ->relationship('months', 'name')
                ->preload()
                    ->multiple(),
                    // ->options([
                    //     'January' => 'January',
                    //     'February' => 'February',
                    //     'March' => 'March',
                    //     'April' => 'April',
                    //     'May' => 'May',
                    //     'June' => 'June',
                    //     'July' => 'July',
                    //     'August' => 'August',
                    //     'September' => 'September',
                    //     'October' => 'October',
                    //     'November' => 'November',
                    //     'December' => 'December',
                    // ]),
                Forms\Components\TextInput::make('name_of_just_in_time_training')
                ->label(__('securityManager.name_of_just_in_time_training')),
                Forms\Components\DatePicker::make('date_of_just_in_time_training')
                ->label(__('securityManager.date_of_just_in_time_training')),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('occupational_health_and_safety_assessment.name')
                    ->label(__('securityManager.occupational_health_and_safety_assessment'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('osh_y_n_facility_assessment.name')
                    ->label(__('securityManager.osh_y_n_facility_assessment'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('development_of_an_incident_action.name')
                    ->label(__('securityManager.development_of_an_incident_action'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('other_training_on_osh.name')
                    ->label(__('securityManager.other_training_on_osh'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('training_received_in_the_field_of_expertise.name')
                    ->label(__('securityManager.training_received_in_the_field_of_expertise'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user.name')
                    ->label(__('univ.user'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('do_you_have_a_service_passport')
                    ->label(__('securityManager.do_you_have_a_service_passport'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('eir_volunteer')
                    ->label(__('securityManager.eir_volunteer'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('national_training_insert_name_and_date_of_just_in_time')
                    ->label(__('securityManager.national_training_insert_name_and_date_of_just_in_time'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('name_of_just_in_time_training')
                    ->label(__('securityManager.name_of_just_in_time_training'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('date_of_just_in_time_training')
                    ->label(__('securityManager.date_of_just_in_time_training'))
                    ->date()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                    Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.created_at')),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.updated_at')),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->label(__('univ.deleted_at'))
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListSecurityManagerExperiences::route('/'),
            'create' => Pages\CreateSecurityManagerExperience::route('/create'),
            'edit' => Pages\EditSecurityManagerExperience::route('/{record}/edit'),
        ];
    }    
}
