<?php

namespace App\Filament\Widgets;

use App\Models\DeploymentOpportunity;
use App\Models\RequestDatabase;
use Filament\Actions\CreateAction;
use Filament\Forms;
use Filament\Forms\Components\Fieldset;
use Filament\Infolists\Components\TextEntry;
use Filament\Tables;
use Filament\Tables\Actions\EditAction;
use Filament\Tables\Table;
use Filament\Widgets\TableWidget as BaseWidget;
use App\Models\DeploymentApplication;




class Latestopportunitites extends BaseWidget

{
    protected int | string | array $columnSpan = 'full';

    protected static ?string $heading = 'Latest Deployment opportunitties';
    
    protected static ?int $sort = 3;

    protected function getTableHeaderActions(): array
    {
        return [
            CreateAction::make()
                ->url(route('deployment-opportunities/create')),
        ];
    }

    public function table(Table $table): Table
    {
        return $table
            ->query(
                DeploymentOpportunity::latest()->limit(5)
            )
            ->columns([
            Tables\Columns\TextColumn::make('id')
                    ->label(__('ID'))
                    ->sortable(),
                Tables\Columns\TextColumn::make('event_name')
                    ->label(__('deploymentOpportunity.event_name'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('request.request_name')
                    ->label(__('deploymentOpportunity.request'))
                    ->numeric()
                    ->sortable()
                    ->wrap(),
                Tables\Columns\TextColumn::make('location_province_region.name')
                    ->label(__('deploymentOpportunity.location_province_region'))
                    ->numeric()
                    ->sortable(),
                    Tables\Columns\TextColumn::make('expected_deployment_start_date')
                    ->label(__('deploymentOpportunity.expected_deployment_start_date'))
                    ->date()
                    ->badge()
                    
            ])
            ->defaultSort('id', 'desc')
            ->actions([
                Tables\Actions\ViewAction::make()
                ->form([
                    Forms\Components\Select::make('request_id')
                        ->label(__('deploymentOpportunity.request'))
                        ->options(RequestDatabase::where('request_approval','Approved')->pluck('request_name','id'))
                        ->required(),
                    Forms\Components\TextInput::make('event_name')
                        ->label(__('deploymentOpportunity.event_name'))
                        ->maxLength(255),
                    Forms\Components\Select::make('logistics_administrator_id')
                        ->label(__('deploymentOpportunity.logistics_administrator'))
                        ->relationship('logistics_administrator', 'name')
                        ->required(),
                    Forms\Components\Select::make('location_province_region_id')
                        ->label(__('deploymentOpportunity.location_province_region'))
                        ->relationship('location_province_region', 'name')
                        ->required(),
                    Forms\Components\TextInput::make('posting_number')
                        ->label(__('deploymentOpportunity.posting_number'))
                        ->numeric(),
                    
                    Forms\Components\TextInput::make('deployer_position_title')
                        ->label(__('deploymentOpportunity.deployer_position_title'))
                        ->maxLength(255)
                        ->label(__('Deployee Skills')),
                    Forms\Components\DatePicker::make('expected_deployment_start_date')
                        ->label(__('deploymentOpportunity.expected_deployment_start_date')),
                    Forms\Components\DatePicker::make('actual_deployment_start_date')
                        ->label(__('deploymentOpportunity.actual_deployment_start_date')),
                    Forms\Components\DatePicker::make('expected_deployment_end_date')
                        ->label(__('deploymentOpportunity.expected_deployment_end_date')),
                    Forms\Components\DatePicker::make('actual_deployment_end_date')
                        ->label(__('deploymentOpportunity.actual_deployment_end_date')),
                    Forms\Components\TextInput::make('number_of_deployers')
                        ->label(__('deploymentOpportunity.number_of_deployers'))
                        ->numeric(),
                    Forms\Components\TextInput::make('location_city')
                        ->label(__('deploymentOpportunity.location_city'))
                        ->maxLength(255),
                    Forms\Components\Textarea::make('language_required')
                        ->label(__('deploymentOpportunity.language_required'))
                        ->columnSpanFull(),
                ]),
                EditAction::make()
                    
                    ->form([
                    Forms\Components\Select::make('request_id')
                        ->label(__('deploymentOpportunity.request'))
                        ->options(RequestDatabase::where('request_approval','Approved')->pluck('request_name','id'))
                        ->required(),
                    Forms\Components\TextInput::make('event_name')
                        ->label(__('deploymentOpportunity.event_name'))
                        ->maxLength(255),
                    Forms\Components\Select::make('logistics_administrator_id')
                        ->label(__('deploymentOpportunity.logistics_administrator'))
                        ->relationship('logistics_administrator', 'name')
                        ->required(),
                    Forms\Components\Select::make('location_province_region_id')
                        ->label(__('deploymentOpportunity.location_province_region'))
                        ->relationship('location_province_region', 'name')
                        ->required(),
                    Forms\Components\TextInput::make('posting_number')
                        ->label(__('deploymentOpportunity.posting_number'))
                        ->numeric(),
                    
                    Forms\Components\TextInput::make('deployer_position_title')
                        ->label(__('deploymentOpportunity.deployer_position_title'))
                        ->maxLength(255)
                        ->label(__('Deployee Skills')),
                    Forms\Components\DatePicker::make('expected_deployment_start_date')
                        ->label(__('deploymentOpportunity.expected_deployment_start_date')),
                    Forms\Components\DatePicker::make('actual_deployment_start_date')
                        ->label(__('deploymentOpportunity.actual_deployment_start_date')),
                    Forms\Components\DatePicker::make('expected_deployment_end_date')
                        ->label(__('deploymentOpportunity.expected_deployment_end_date')),
                    Forms\Components\DatePicker::make('actual_deployment_end_date')
                        ->label(__('deploymentOpportunity.actual_deployment_end_date')),
                    Forms\Components\TextInput::make('number_of_deployers')
                        ->label(__('deploymentOpportunity.number_of_deployers'))
                        ->numeric(),
                    Forms\Components\TextInput::make('location_city')
                        ->label(__('deploymentOpportunity.location_city'))
                        ->maxLength(255),
                    Forms\Components\Textarea::make('language_required')
                        ->label(__('deploymentOpportunity.language_required'))
                        ->columnSpanFull(),
                ])
                ->hidden(!auth()->user()->hasAnyRole('Admin')),
                Tables\Actions\Action::make('Apply')
                ->action(function (DeploymentOpportunity $record) {                    
                    $user = auth()->user();
                    $applicationData = [
                        'deployment_opportunity_id' => $record->id,
                        'user_id' => $user->id,
                    ];
                    // Update or create the deployment application record
                    $record = DeploymentApplication::updateOrCreate(
                        $applicationData,
                        $applicationData
                    );
                    $deploymentApplication = DeploymentApplication::find($record->id);

                    if (!$deploymentApplication->user()->find($user->id)) {
                        
                        $deploymentApplication->user()->attach($user->id);
                        
                        // $recipient = auth()->user();

                        // Notification::make()
                        //     ->title('Saved successfully')
                        //     ->broadcast($recipient);
                    }

                })
                ->hidden(auth()->user()->hasAnyRole('Admin'))
                ->hidden(!auth()->user()->hasAnyRole('')),
            ])            
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
                Tables\Actions\DeleteAction::make(),
            ]);
            
    }

    public static function infolist(Infolist $infolist): Infolist
    {
        return $infolist
            ->schema([
                TextEntry::make('event_name')
                    ->label(__('deploymentOpportunity.event_name')),
                TextEntry::make('request.request_name')
                    ->label(__('deploymentOpportunity.request')),
                TextEntry::make('location_province_region.name')
                    ->label(__('deploymentOpportunity.location_province_region')),
                TextEntry::make('logistics_administrator.name')
                    ->label(__('deploymentOpportunity.logistics_administrator')),
                TextEntry::make('posting_number')
                    ->label(__('deploymentOpportunity.deployer_position_title')),
                TextEntry::make('deployer_position_title'),
                Fieldset::make(__('deploymentOpportunity.key_dates'))
                    ->schema([
                        TextEntry::make('expected_deployment_start_date')
                            ->label(__('deploymentOpportunity.expected_deployment_start_date'))
                            ->badge()
                            ->dateTime('d/m/Y'),
                        TextEntry::make('actual_deployment_start_date')
                            ->label(__('deploymentOpportunity.actual_deployment_start_date'))
                            ->badge()
                            ->dateTime('d/m/Y'),
                        TextEntry::make('expected_deployment_end_date')
                            ->label(__('deploymentOpportunity.expected_deployment_end_date'))
                            ->badge()
                            ->dateTime('d/m/Y'),
                        TextEntry::make('actual_deployment_end_date')
                            ->label(__('deploymentOpportunity.actual_deployment_end_date'))
                            ->badge()
                            ->dateTime('d/m/Y'),
                        
                    ]),
                
                TextEntry::make('number_of_deployers')
                    ->label(__('deploymentOpportunity.number_of_deployers')),
                TextEntry::make('location_city')
                    ->label(__('deploymentOpportunity.location_city')),
                TextEntry::make('location_city')
                    ->label(__('deploymentOpportunity.language_required')),
            ]);
    }
    


    public static function getPages(): array
    {
        return [
            'index' => Pages\ListDeploymentOpportunities::route('/'),
            // 'create' => Pages\CreateDeploymentOpportunity::route('/create'),
            // 'edit' => Pages\EditDeploymentOpportunity::route('/{record}/edit'),
            // 'view' => Pages\ViewDeploymentOpportunity::route('/{record}'),
        ];
    }    

    
}
