<?php

namespace App\Models;

use \DateTimeInterface;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;


class DeploymentOpportunity extends Model 
//implements HasMedia
{
    use SoftDeletes;
    //use InteractsWithMedia;
    use HasFactory;

    public $table = 'deployment_opportunities';

    protected $dates = [
        'expected_deployment_start_date',
        'actual_deployment_start_date',
        'expected_deployment_end_date',
        'actual_deployment_end_date',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'name',
        'region_id',
        'posting_number',
        'narrative',
        'logistics_administrator_id',
        'event_name',
        'deployer_position_title',
        'expected_deployment_start_date',
        'actual_deployment_start_date',
        'expected_deployment_end_date',
        'actual_deployment_end_date',
        'number_of_deployers',
        'location_city',
        'location_province_region_id',
        'language_required',
        'request_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    // public function registerMediaConversions(Media $media = null): void
    // {
    //     $this->addMediaConversion('thumb')->fit('crop', 50, 50);
    //     $this->addMediaConversion('preview')->fit('crop', 120, 120);
    // }

    public function region()
    {
        return $this->belongsTo(Region::class, 'region_id');
    }

    public function logistics_administrator()
    {
        return $this->belongsTo(User::class, 'logistics_administrator_id');
    }


    public function location_province_region()
    {
        return $this->belongsTo(Region::class, 'location_province_region_id');
    }
       public function deployment_application()
    {
        return $this->hasMany(DeploymentApplication::class);
    }
       public function admin_user_deployment_application()
    {
        return $this->belongsToMany(UserData::class)
                     ->withPivot('status', 'user_response')
                     ->withTimestamps();

                     
    }


    
    

    public function request()
    {
        return $this->belongsTo(RequestDatabase::class, 'request_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
    
     public function users()
    {
        return $this->belongsToMany(User::class);
    }

    public function user_data()
    {
        return $this->belongsTo(UserData::class, 'user_id');
    }

     public function deployment_role()
    {
        return $this->belongsToMany(DeploymentRole::class, 'deployment_opportunity_deployment_role');
    }
}