<?php

namespace App\Models;

use Carbon\Carbon;
use DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Models\Traits\Multitenantable;
use App\Models\Month;

class SecurityManagerExperience extends Model
{
    use SoftDeletes, HasFactory;
    use Multitenantable;

    public $table = 'security_manager_experiences';

    public const EIR_VOLUNTEER_RADIO = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    public const DO_YOU_HAVE_A_SERVICE_PASSPORT_RADIO = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    protected $dates = [
        'date_of_just_in_time_training',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public const NATIONAL_TRAINING_INSERT_NAME_AND_DATE_OF_JUST_IN_TIME_RADIO = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    protected $fillable = [
        'occupational_health_and_safety_assessment_id',
        'osh_y_n_facility_assessment_id',
        'development_of_an_incident_action_id',
        'other_training_on_osh_id',
        'training_received_in_the_field_of_expertise_id',
        'do_you_have_a_service_passport',
        'eir_volunteer',
        'national_training_insert_name_and_date_of_just_in_time',
        'name_of_just_in_time_training',
        'date_of_just_in_time_training',
        'user_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function occupational_health_and_safety_assessment()
    {
        return $this->belongsTo(TrainingLevel::class, 'occupational_health_and_safety_assessment_id');
    }

    public function osh_y_n_facility_assessment()
    {
        return $this->belongsTo(TrainingLevel::class, 'osh_y_n_facility_assessment_id');
    }

    public function development_of_an_incident_action()
    {
        return $this->belongsTo(TrainingLevel::class, 'development_of_an_incident_action_id');
    }

    public function other_training_on_osh()
    {
        return $this->belongsTo(TrainingLevel::class, 'other_training_on_osh_id');
    }

    public function training_received_in_the_field_of_expertise()
    {
        return $this->belongsTo(TrainingLevel::class, 'training_received_in_the_field_of_expertise_id');
    }

    public function months()
    {
        return $this->belongsToMany(Month::class);
    }

    // public function getDateOfJustInTimeTrainingAttribute($value)
    // {
    //     return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    // }

    // public function setDateOfJustInTimeTrainingAttribute($value)
    // {
    //     $this->attributes['date_of_just_in_time_training'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    // }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }
}
