<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use Spatie\Permission\Traits\HasRoles;
use Illuminate\Database\Eloquent\SoftDeletes;


class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, HasRoles, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];


    protected $fillable = [
        'name',
        'email',
        'password',
        'deleted_at',
        'created_at',
        'updated_at',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    // protected function deployment_applicaton() 
    // {
    //     return $this->BelongsToMany(DeploymentApplication::class);
    // }
    
    public function deploymentOpportunities()
    {
        return $this->belongsToMany(DeploymentOpportunity::class, 'deployment_application');
    }
    
     public function case_management()
    {
        return $this->hasOne(CaseManagement::class, 'user_id');
    }
     public function data_management()
    {
        return $this->hasOne(DataManagement::class, 'user_id');
    }
     public function crec()
    {
        return $this->hasOne(Crec::class, 'user_id');
     }

    public function canAccessFilament(): bool
    {
        return  $this->hasVerifiedEmail();
    }

    //  protected static function booted(): void
    // {
    //     static::creating(function (User $user) {
    //         $user->role = 'user';
    //     });
    // }
}
