<?php

namespace App\Policies;

use App\Models\User;
use App\Models\DiseaseEmergency;
use Illuminate\Auth\Access\HandlesAuthorization;

class DiseaseEmergencyPolicy
{
    use HandlesAuthorization;

    /**
     * Determine whether the user can view any models.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function viewAny(User $user): bool
    {
        return $user->can('view_any_disease::emergency');
    }

    /**
     * Determine whether the user can view the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\DiseaseEmergency  $diseaseEmergency
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function view(User $user, DiseaseEmergency $diseaseEmergency): bool
    {
        return $user->can('view_disease::emergency');
    }

    /**
     * Determine whether the user can create models.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function create(User $user): bool
    {
        return $user->can('create_disease::emergency');
    }

    /**
     * Determine whether the user can update the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\DiseaseEmergency  $diseaseEmergency
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function update(User $user, DiseaseEmergency $diseaseEmergency): bool
    {
        return $user->can('update_disease::emergency');
    }

    /**
     * Determine whether the user can delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\DiseaseEmergency  $diseaseEmergency
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function delete(User $user, DiseaseEmergency $diseaseEmergency): bool
    {
        return $user->can('delete_disease::emergency');
    }

    /**
     * Determine whether the user can bulk delete.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function deleteAny(User $user): bool
    {
        return $user->can('delete_any_disease::emergency');
    }

    /**
     * Determine whether the user can permanently delete.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\DiseaseEmergency  $diseaseEmergency
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function forceDelete(User $user, DiseaseEmergency $diseaseEmergency): bool
    {
        return $user->can('force_delete_disease::emergency');
    }

    /**
     * Determine whether the user can permanently bulk delete.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function forceDeleteAny(User $user): bool
    {
        return $user->can('force_delete_any_disease::emergency');
    }

    /**
     * Determine whether the user can restore.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\DiseaseEmergency  $diseaseEmergency
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function restore(User $user, DiseaseEmergency $diseaseEmergency): bool
    {
        return $user->can('restore_disease::emergency');
    }

    /**
     * Determine whether the user can bulk restore.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function restoreAny(User $user): bool
    {
        return $user->can('restore_any_disease::emergency');
    }

    /**
     * Determine whether the user can replicate.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\DiseaseEmergency  $diseaseEmergency
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function replicate(User $user, DiseaseEmergency $diseaseEmergency): bool
    {
        return $user->can('replicate_disease::emergency');
    }

    /**
     * Determine whether the user can reorder.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function reorder(User $user): bool
    {
        return $user->can('reorder_disease::emergency');
    }

}
