<?php

namespace App\Policies;

use App\Models\User;
use App\Models\InfectionPreventControl;
use Illuminate\Auth\Access\HandlesAuthorization;

class InfectionPreventControlPolicy
{
    use HandlesAuthorization;

    /**
     * Determine whether the user can view any models.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function viewAny(User $user): bool
    {
        return $user->can('view_any_infection::prevent::control');
    }

    /**
     * Determine whether the user can view the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\InfectionPreventControl  $infectionPreventControl
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function view(User $user, InfectionPreventControl $infectionPreventControl): bool
    {
        return $user->can('view_infection::prevent::control');
    }

    /**
     * Determine whether the user can create models.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function create(User $user): bool
    {
        return $user->can('create_infection::prevent::control');
    }

    /**
     * Determine whether the user can update the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\InfectionPreventControl  $infectionPreventControl
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function update(User $user, InfectionPreventControl $infectionPreventControl): bool
    {
        return $user->can('update_infection::prevent::control');
    }

    /**
     * Determine whether the user can delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\InfectionPreventControl  $infectionPreventControl
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function delete(User $user, InfectionPreventControl $infectionPreventControl): bool
    {
        return $user->can('delete_infection::prevent::control');
    }

    /**
     * Determine whether the user can bulk delete.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function deleteAny(User $user): bool
    {
        return $user->can('delete_any_infection::prevent::control');
    }

    /**
     * Determine whether the user can permanently delete.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\InfectionPreventControl  $infectionPreventControl
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function forceDelete(User $user, InfectionPreventControl $infectionPreventControl): bool
    {
        return $user->can('force_delete_infection::prevent::control');
    }

    /**
     * Determine whether the user can permanently bulk delete.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function forceDeleteAny(User $user): bool
    {
        return $user->can('force_delete_any_infection::prevent::control');
    }

    /**
     * Determine whether the user can restore.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\InfectionPreventControl  $infectionPreventControl
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function restore(User $user, InfectionPreventControl $infectionPreventControl): bool
    {
        return $user->can('restore_infection::prevent::control');
    }

    /**
     * Determine whether the user can bulk restore.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function restoreAny(User $user): bool
    {
        return $user->can('restore_any_infection::prevent::control');
    }

    /**
     * Determine whether the user can replicate.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\InfectionPreventControl  $infectionPreventControl
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function replicate(User $user, InfectionPreventControl $infectionPreventControl): bool
    {
        return $user->can('replicate_infection::prevent::control');
    }

    /**
     * Determine whether the user can reorder.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Auth\Access\Response|bool
     */
    public function reorder(User $user): bool
    {
        return $user->can('reorder_infection::prevent::control');
    }

}
